@@ -7,25 +7,22 @@
 #define OPENBLAS_PTHREAD_CREATE_FUNC pthread_create
 #define OPENBLAS_BUNDERSCORE _
 #define OPENBLAS_NEEDBUNDERSCORE 1
-#define OPENBLAS_BULLDOZER 
-#define OPENBLAS_L1_CODE_SIZE 65536
-#define OPENBLAS_L1_CODE_ASSOCIATIVE 2
+#define OPENBLAS_HASWELL 
+#define OPENBLAS_L1_CODE_SIZE 32768
+#define OPENBLAS_L1_CODE_ASSOCIATIVE 8
 #define OPENBLAS_L1_CODE_LINESIZE 64
-#define OPENBLAS_L1_DATA_SIZE 65536
-#define OPENBLAS_L1_DATA_ASSOCIATIVE 2
+#define OPENBLAS_L1_DATA_SIZE 32768
+#define OPENBLAS_L1_DATA_ASSOCIATIVE 8
 #define OPENBLAS_L1_DATA_LINESIZE 64
-#define OPENBLAS_L2_SIZE 2097152
+#define OPENBLAS_L2_SIZE 262144
 #define OPENBLAS_L2_ASSOCIATIVE 8
 #define OPENBLAS_L2_LINESIZE 64
-#define OPENBLAS_L3_SIZE 16777216
-#define OPENBLAS_L3_ASSOCIATIVE 8
-#define OPENBLAS_L3_LINESIZE 64
-#define OPENBLAS_ITB_SIZE 4096
-#define OPENBLAS_ITB_ASSOCIATIVE 1
-#define OPENBLAS_ITB_ENTRIES 255
+#define OPENBLAS_ITB_SIZE 2097152
+#define OPENBLAS_ITB_ASSOCIATIVE 0
+#define OPENBLAS_ITB_ENTRIES 8
 #define OPENBLAS_DTB_SIZE 4096
-#define OPENBLAS_DTB_ASSOCIATIVE 1
-#define OPENBLAS_DTB_DEFAULT_ENTRIES 255
+#define OPENBLAS_DTB_ASSOCIATIVE 4
+#define OPENBLAS_DTB_DEFAULT_ENTRIES 64
 #define OPENBLAS_HAVE_CMOV 
 #define OPENBLAS_HAVE_MMX 
 #define OPENBLAS_HAVE_SSE 
@@ -34,21 +31,20 @@
 #define OPENBLAS_HAVE_SSSE3 
 #define OPENBLAS_HAVE_SSE4_1 
 #define OPENBLAS_HAVE_SSE4_2 
-#define OPENBLAS_HAVE_SSE4A 
 #define OPENBLAS_HAVE_AVX 
-#define OPENBLAS_HAVE_FMA4 
+#define OPENBLAS_HAVE_AVX2 
+#define OPENBLAS_HAVE_FMA3 
 #define OPENBLAS_HAVE_CFLUSH 
-#define OPENBLAS_HAVE_MISALIGNSSE 
-#define OPENBLAS_NUM_SHAREDCACHE 1
-#define OPENBLAS_NUM_CORES 1
-#define OPENBLAS_CORE_BULLDOZER 
-#define OPENBLAS_CHAR_CORENAME "BULLDOZER"
-#define OPENBLAS_SLOCAL_BUFFER_SIZE 5376
-#define OPENBLAS_DLOCAL_BUFFER_SIZE 5376
-#define OPENBLAS_CLOCAL_BUFFER_SIZE 14336
-#define OPENBLAS_ZLOCAL_BUFFER_SIZE 14336
+#define OPENBLAS_NUM_SHAREDCACHE 2
+#define OPENBLAS_NUM_CORES 16
+#define OPENBLAS_CORE_HASWELL 
+#define OPENBLAS_CHAR_CORENAME "HASWELL"
+#define OPENBLAS_SLOCAL_BUFFER_SIZE 24576
+#define OPENBLAS_DLOCAL_BUFFER_SIZE 32768
+#define OPENBLAS_CLOCAL_BUFFER_SIZE 12288
+#define OPENBLAS_ZLOCAL_BUFFER_SIZE 8192
 #define OPENBLAS_GEMM_MULTITHREAD_THRESHOLD 4
-#define OPENBLAS_VERSION " OpenBLAS 0.3.6 "
+#define OPENBLAS_VERSION " OpenBLAS 0.3.7 "
 /*This is only for "make install" target.*/
 
 #if defined(OPENBLAS_OS_WINNT) || defined(OPENBLAS_OS_CYGWIN_NT) || defined(OPENBLAS_OS_INTERIX)
